#!/usr/bin/env sh
#
#  test.short.sh
#
#  Created by CC on 2018/10/12.
#  Copyright 2018 - now youhua deng (deng you hua | CC) <ccworld1000@gmail.com>
#  https://github.com/ccworld1000/CCLog
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#
#
    
perl6 ccnormal.error.p6
perl6 ccnormal.ok.p6
perl6 ccwarning.error.p6
perl6 ccwarning.ok.p6
perl6 ccerror.error.p6
perl6 ccerror.ok.p6
perl6 cctimer.error.p6
perl6 cctimer.ok.p6
perl6 ccloop.error.p6
perl6 ccloop.ok.p6
perl6 ccthread.error.p6
perl6 ccthread.ok.p6
perl6 ccprint.error.p6
perl6 ccprint.ok.p6
perl6 ccsay.error.p6
perl6 ccsay.ok.p6
perl6 ccdie.error.p6
perl6 ccdie.ok.p6
perl6 ccnetwork.error.p6
perl6 ccnetwork.ok.p6
