#!/usr/bin/env sh
#
#  test.bin.sh
#
#  Created by CC on 2018/10/12.
#  Copyright 2018 - now youhua deng (deng you hua | CC) <ccworld1000@gmail.com>
#  https://github.com/ccworld1000/CCLog
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#
#
    
./ccnormal	"test ccnormal"
./ccwarning	"test ccwarning"
./ccerror	"test ccerror"
./cctimer	"test cctimer"
./ccloop	"test ccloop"
./ccthread	"test ccthread"
./ccprint	"test ccprint"
./ccsay	"test ccsay"
./ccdie	"test ccdie"
./ccnetwork	"test ccnetwork"
